@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-01-09'; # DATE
 our $DIST = 'Sah-Schemas-Business-ID-NIK'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $schema = [str => {
     summary => 'Indonesian citizenship registration number (NIK)',
@@ -38,7 +38,7 @@ Sah::Schema::business::id::nik - Indonesian citizenship registration number (NIK
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::business::id::nik (from Perl distribution Sah-Schemas-Business-ID-NIK), released on 2024-01-09.
+This document describes version 0.003 of Sah::Schema::business::id::nik (from Perl distribution Sah-Schemas-Business-ID-NIK), released on 2024-01-09.
 
 =head1 SAH SCHEMA DEFINITION
 
@@ -84,12 +84,12 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = 3273010101900005;
+ $data = "3273 0101 0190 0005";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = 3273010131900005;
- my $errmsg = $validator->($data); # => "Invalid date of birth: 01-31-1990"
+ $data = "";
+ my $errmsg = $validator->($data); # => "Please specify nik"
 
 Often a schema has coercion rule or default value rules, so after validation the
 validated value will be different from the original. To return the validated
@@ -99,12 +99,12 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = 3273010101900005;
+ $data = "3273 0101 0190 0005";
  my $res = $validator->($data); # => ["",3273010101900005]
  
  # a sample invalid data
- $data = 3273010131900005;
- my $res = $validator->($data); # => ["Invalid date of birth: 01-31-1990",3273010131900005]
+ $data = "";
+ my $res = $validator->($data); # => ["Please specify nik",""]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
